==> owncloud-10.0.8.tar.bz2: owncloud/core/l10n/af_ZA.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Kies asseblief 'n lêer.",
    "File is too big" : "Die lêer is te groot",
    "Invalid file provided" : "Ongeldige lêer voorsien",
    "No image or file provided" : "Geen prent of lêer voorsien",
    "Unknown filetype" : "Onbekende lêertipe",
    "Invalid image" : "Ongeldige prent",
    "An error occurred. Please contact your admin." : "'n Fout het voorgekom. Kontak asseblief jou stelsel administrateur.",
    "No temporary profile picture available, try again" : "Geen tydelike profiel foto beskikbaar nie, probeer weer",
    "No crop data provided" : "Geen \"crop\" data verskaf",
    "%s password reset" : "%s wagwoord herstel",
    "Couldn't send reset email. Please contact your administrator." : "Die herstel epos kon nie gestuur word nie. Kontak asseblief die stelsel administrateur.",
    "Couldn't send mail to following users: %s " : "Kon nie e-pos aan die volgende gebruikers stuur nie: %s",
    "Repair warning: " : "Herstel waarskuwing:",
    "Repair error: " : "Herstel fout:",
    "Turned on maintenance mode" : "Instandhouding aangeskakel",
    "Turned off maintenance mode" : "Instandhouding afgeskakel",
    "Updated database" : "Databasis opgedateer",
    "Checked database schema update" : "Databasis skema opdatering nagegaan",
    "Checked database schema update for apps" : "Databasis skema opdatering nagegaan vir sagteware",
    "Updated \"%s\" to %s" : "\"%s\" opgedateer na %s",
    "Sunday" : "Sondag",
    "Monday" : "Maandag",
    "Tuesday" : "Dinsdag",
    "Wednesday" : "Woensdag",
    "Thursday" : "Donderdag",
    "Friday" : "Vrydag",
    "Saturday" : "Saterdag",
    "January" : "Januarie",
    "February" : "Februarie",
    "March" : "Maart",
    "April" : "April",
    "May" : "Mei",
    "June" : "Junie",
    "July" : "Julie",
    "August" : "Augustus",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Settings" : "Instellings",
    "Saving..." : "Stoor...",
    "seconds ago" : "sekondes gelede",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Die \"link\" vir die herstel van jou wagwoord is na jou epos gestuur. As jy dit nie binne 'n redelike tyd ontvang nie, soek deur jou \"spam/junk\" omslagte.<br>As dit nie daar is nie vra jou administrateur vir hulp.",
    "I know what I'm doing" : "Ek weet wat ek doen",
    "Password can not be changed. Please contact your administrator." : "Wagwoord kan nie verander word nie. Kontak asseblief jou stelsel administrateur.",
    "No" : "Nee",
    "Yes" : "Ja",
    "Choose" : "Kies",
    "Ok" : "OK",
    "One file conflict" : "Een lêer konflik",
    "New Files" : "Nuwe lêers",
    "Already existing files" : "Bestaande lêers",
    "Which files do you want to keep?" : "Watse lêers wil jy hou?",
    "Cancel" : "Kanselleer",
    "Continue" : "Gaan voort",
    "Very weak password" : "Baie swak wagwoord",
    "Weak password" : "Swak wagwoord",
    "So-so password" : "So-so wagwoord",
    "Good password" : "Goeie wagwoord",
    "Strong password" : "Sterk wagwoord",
    "Shared" : "Gedeel",
    "Error" : "Fout",
    "Error while sharing" : "Deel veroorsaak fout",
    "Error while unsharing" : "Deel terugneem veroorsaak fout",
    "Set expiration date" : "Stel verval datum",
    "Expiration date" : "Verval datum",
    "Password" : "Wagwoord",
    "Sending ..." : "Stuur ...",
    "Email sent" : "E-pos gestuur",
    "Email link to person" : "E-pos aan persoon",
    "Shared with you and the group {group} by {owner}" : "Met jou en die groep {group} gedeel deur {owner}",
    "Shared with you by {owner}" : "Met jou gedeel deur {owner}",
    "group" : "groep",
    "Unshare" : "Deel terug neem",
    "can edit" : "kan wysig",
    "create" : "skep",
    "delete" : "uitvee",
    "access control" : "toegang beheer",
    "Share" : "Deel",
    "Resharing is not allowed" : "Herdeling is nie toegelaat nie ",
    "Warning" : "Waarskuwing",
    "The object type is not specified." : "Hierdie objek tipe is nie gespesifiseer nie.",
    "Add" : "Voeg by",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Die opdatering was nie suksesvol nie. Rapporteer die probleem by <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Die opdatering was suksesvol. Jy word nou aan ownCloud terug gelei.",
    "Personal" : "Persoonlik",
    "Users" : "Gebruikers",
    "Apps" : "Toepassings",
    "Admin" : "Admin",
    "Help" : "Hulp",
    "Access forbidden" : "Toegang verbode",
    "Create an <strong>admin account</strong>" : "Skep `n <strong>admin-rekening</strong>",
    "Username" : "Gebruikersnaam",
    "Data folder" : "Data omslag",
    "Configure the database" : "Stel databasis op",
    "Database user" : "Databasis-gebruiker",
    "Database password" : "Databasis-wagwoord",
    "Database name" : "Databasis naam",
    "Database tablespace" : "Databasis tabelspasie",
    "Database host" : "Databasis gasheer",
    "Finish setup" : "Maak opstelling klaar",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Halo daar,<br><br>wou jou net laat weet dat %s <strong>%s</strong> met jou gedeel het.<br><a href=\"%s\">Sien alles!</a><br><br>",
    "Log out" : "Teken uit",
    "Log in" : "Teken aan",
    "Alternative Logins" : "Alternatiewe aantekeninge",
    "Use the following link to reset your password: {link}" : "Gebruik die volgende skakel om jou wagwoord te herstel: {link}",
    "New password" : "Nuwe wagwoord",
    "Reset password" : "Herstel wagwoord",
    "No valid crop data provided" : "Geen geldige snoeidata verskaf",
    "Crop is not square" : "Snoei is nie vierkantig nie",
    "Could not reset password because the token is invalid" : "Kon nie wagwoord herstel nie want die teken is ongeldig",
    "Could not reset password because the token expired" : "Kon nie wagwoord herstel nie want die teken het verstryk",
    "Could not reset password because the token does not match" : "Kon nie wagwoord herstel nie want die teken stem nie ooreen nie",
    "Preparing update" : "Berei tans bywerking voor",
    "Checking updates of apps" : "Gaan tans toepbywerkings na",
    "Following apps have been disabled: %s" : "Die volgende toeps is gedeaktiveer: %s",
    "Already up to date" : "Reeds bygewerk",
    "Su" : "So",
    "Mo" : "Ma",
    "Tu" : "Di",
    "We" : "Wo",
    "Th" : "Do",
    "Fr" : "Vr",
    "Sat." : "Sa.",
    "Dismiss" : "Wys af",
    "read-only" : "leesalleen",
    "Error loading file exists template" : "Bestaandelêersjabloonlaaifout",
    "The public link will expire no later than {days} days after it is created" : "Die openbare skakel sal nie later nie as {days} dae veral nadat dit geskep is",
    "Expiration" : "Verval",
    "Expiration date is required" : "Vervaldatum word benodig",
    "Remove link" : "Verwyder skakel",
    "Link" : "Skakel",
    "Create public link" : "Skep openbare skakel",
    "Edit" : "Wysig",
    "Copy to clipboard" : "Kopieer na knipbord",
    "There are currently no link shares, you can create one" : "Daar is tans geen skakeldelings nie, u kan een skep",
    "Anyone with the link has access to the file/folder" : "Enigeen met die skakel het toegang tot die lêer/vouer",
    "Choose a password" : "Kies ’n wagwoord",
    "Password required" : "Wagwoord benodig",
    "Name" : "Naam",
    "Filename" : "Lêernaam",
    "Upload only" : "Slegs oplaai",
    "Save" : "Bewaar",
    "Remove password" : "Verwyder wagwoord",
    "Send link via email" : "Stuur skakel d.m.v. e-pos",
    "Sending" : "Stuur tans",
    "notify by email" : "laat weet d.m.v. e-pos",
    "can share" : "kan deel",
    "change" : "verander",
    "An error occurred. Please try again" : "’n Fout het voorgekom. Probeer weer",
    "User and Groups" : "Gebruiker en Groepe",
    "Public Links" : "Openbare Skakels",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Deel met mense op ander ownClouds deur die sintaks gebruikernaam@voorbeeld.com/owncloud te gebruik",
    "restricted" : "beperk",
    "invisible" : "onsigbaar",
    "Delete {link}" : "Skrap {link}",
    "Rename" : "Hernoem",
    "unknown text" : "onbekende teks",
    "sunny" : "sonnig",
    "Share to Twitter. Opens in a new window." : "Deel na Twitter. Open in ’n nuwe venster.",
    "File not found" : "Lêer nie gevind",
    "Internal Server Error" : "Internebedienerfout",
    "Technical details" : "Tegniese details",
    "Remote Address: %s" : "Afstandsadres: %s",
    "Request ID: %s" : "Versoek-ID: %s",
    "Type: %s" : "Tipe: %s",
    "Code: %s" : "Kode: %s",
    "Message: %s" : "Boodskap: %s",
    "File: %s" : "Lêer: %s",
    "Line: %s" : "Lyn: %s",
    "Menu" : "Kieslys",
    "Search" : "Soek",
    "Username or email" : "Gebruikersnaam of e-pos",
    "Stay logged in" : "Bly aangeteken",
    "New Password" : "Nuwe Wagwoord",
    "Error loading file picker template: {error}" : "Lêerkiesersjabloonlaaifout: {error}",
    "%s password changed successfully" : "%s wagwoord suksesvol verander",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "%s (3rdparty)" : "%s (3departy)",
    "%s (incompatible)" : "%s (onversoenbaar)",
    "Sun." : "So.",
    "Mon." : "Ma.",
    "Tue." : "Di.",
    "Wed." : "Wo.",
    "Thu." : "Do.",
    "Fri." : "Vr.",
    "Sa" : "Sa",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mrt.",
    "Apr." : "Apr.",
    "May." : "Mei.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "U lêers is geënkripteer. Indien u nie ’n verhaalsleutel geaktiveer het nie, sal daar geen manier wees om  u data terug te kry nadat u wagwoord herstel is nie. <br />Kontak u administrateur alvorens u voortgaan indien u onseker is. <br />Wil u regtig voortgaan?",
    "Error loading message template: {error}" : "Boodskapsjabloonlaaifout: {error}",
    "(all selected)" : "(alles gekies)",
    "({count} selected)" : "({count} gekies)",
    "Shared with {recipients}" : "Gedeel met {recipients}",
    "{fileName} link" : "{fileName} skakel",
    "Remove" : "Verwyder",
    "Copied!" : "Gekopieer!",
    "Not supported!" : "Nie ondersteun nie!",
    "Press ⌘-C to copy." : "Druk ⌘-C om te kopieer.",
    "Press Ctrl-C to copy." : "Druk Ctrl-C om te kopieer.",
    "Edit link share: {name}" : "Wysig deelskakel: {name}",
    "Create link share: {name}" : "Skep deelskakel: {name}",
    "Share to Facebook. Opens in a new window." : "Deel na Facebook. Open in ’n nuwe venster.",
    "Share to Diaspora. Opens in a new window." : "Deel na Diaspora. Open in ’n nuwe venster.",
    "Share to Google+. Opens in a new window." : "Deel na Google+. Open in ’n nuwe venster.",
    "Share via email. Opens your mail client." : "Deel d.m.v. e-pos. Open u poskliënt.",
    "Owner: {owner}" : "Eienaar: {owner}",
    "Share details could not be loaded for this item." : "Hierdie item se deeldetails kon nie gelaai word nie.",
    "No users or groups found for {search}" : "Geen gebruikers of groepe gevind vir {search}",
    "No users found for {search}" : "Geen gebruikers gevind vir {search}",
    "{sharee} (group)" : "{sharee} (groep)",
    "{sharee} (at {server})" : "{sharee} (by {server})",
    "Share with users…" : "Deel met gebruikers…",
    "Share with users, groups or remote users…" : "Deel met gebruikers, groepe of afstandsgebruikers…",
    "Share with users or groups…" : "Deel met gebruikers of groepe…",
    "Share with users or remote users…" : "Deel met gebruikers of afstandsgebruikers…",
    "Non-existing tag #{tag}" : "Niebestaande merkie #{tag}",
    "({scope})" : "({scope})",
    "Delete" : "Skrap",
    "Error loading dialog template: {error}" : "Dialoogsjabloonlaaifout: {error}",
    "Hello world!" : "Dag wêreld!",
    "Hello {name}, the weather is {weather}" : "Dag {name}, die weer is {weather}",
    "Hello {name}" : "Dag {name}",
    "new" : "nuut",
    "Updating to {version}" : "Werk tans by na {version}",
    "An error occurred." : "’n Fout het voorgekom.",
    "Please reload the page." : "Herlaai asb. die blad.",
    "The update was successful. There were warnings." : "Die bywerking was suksesvol. Daar was waarskuwings.",
    "The share will expire on %s." : "Die deling sal op %s verval.",
    "Cheers!" : "Groete!",
    "Only %s is available." : "Slegs %s is beskikbaar.",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Spesifiseer die poortnommer saam met die gasheernaam (bv. localhost: 5432).",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Hierdie toepassing benodig JavaScript om reg te werk. {linkstart}Aktiveer JavaScript{linkend} en herlaai die blad.",
    "Please contact your administrator." : "Kontak u stelseladministrateur.",
    "An internal error occurred." : "’n Interne fout het voorgekom.",
    "Please try again or contact your administrator." : "Probeer weer of kontak u stelseladministrateur.",
    "Wrong password. Reset it?" : "Verkeerde wagwoord. Herstel dit?",
    "Wrong password." : "Verkeerde wagwoord."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.7.0.tar.bz2: owncloud/core/l10n/af_ZA.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Kies asb. ’n lêer.",
    "File is too big" : "Die lêer is te groot",
    "Invalid file provided" : "Ongeldige lêer voorsien",
    "No image or file provided" : "Geen prent of lêer voorsien",
    "Unknown filetype" : "Onbekende lêertipe",
    "Invalid image" : "Ongeldige prent",
    "An error occurred. Please contact your admin." : "’n Fout het voorgekom. Kontak u stelseladministrateur.",
    "No temporary profile picture available, try again" : "Geen tydelike profielfoto beskikbaar nie, probeer weer",
    "No crop data provided" : "Geen snoeidata verskaf",
    "No valid crop data provided" : "Geen geldige snoeidata verskaf",
    "Crop is not square" : "Snoei is nie vierkantig nie",
    "Could not reset password because the token is invalid" : "Kon nie wagwoord herstel nie want die teken is ongeldig",
    "Could not reset password because the token expired" : "Kon nie wagwoord herstel nie want die teken het verstryk",
    "Could not reset password because the token does not match" : "Kon nie wagwoord herstel nie want die teken stem nie ooreen nie",
    "%s password changed successfully" : "%s wagwoord suksesvol verander",
    "%s password reset" : "%s wagwoord herstel",
    "Couldn't send reset email. Please contact your administrator." : "Herstel-e-pos kon nie gestuur word nie. Kontak u stelseladministrateur.",
    "Upload only" : "Slegs oplaai",
    "Preparing update" : "Berei tans bywerking voor",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Herstelwaarskuwing:",
    "Repair error: " : "Herstelfout:",
    "Turned on maintenance mode" : "Instandhouding aangeskakel",
    "Turned off maintenance mode" : "Instandhouding afgeskakel",
    "Updated database" : "Databasis bygewerk",
    "Checked database schema update" : "Databasisskemabywerking nagegaan",
    "Checking updates of apps" : "Gaan tans toepbywerkings na",
    "Checked database schema update for apps" : "Databasisskemabywerking nagegaan vir toeps",
    "Updated \"%s\" to %s" : "“%s” bygewerk na %s",
    "%s (3rdparty)" : "%s (3departy)",
    "%s (incompatible)" : "%s (onversoenbaar)",
    "Following apps have been disabled: %s" : "Die volgende toeps is gedeaktiveer: %s",
    "Already up to date" : "Reeds bygewerk",
    "Sunday" : "Sondag",
    "Monday" : "Maandag",
    "Tuesday" : "Dinsdag",
    "Wednesday" : "Woensdag",
    "Thursday" : "Donderdag",
    "Friday" : "Vrydag",
    "Saturday" : "Saterdag",
    "Sun." : "So.",
    "Mon." : "Ma.",
    "Tue." : "Di.",
    "Wed." : "Wo.",
    "Thu." : "Do.",
    "Fri." : "Vr.",
    "Sat." : "Sa.",
    "Su" : "So",
    "Mo" : "Ma",
    "Tu" : "Di",
    "We" : "Wo",
    "Th" : "Do",
    "Fr" : "Vr",
    "Sa" : "Sa",
    "January" : "Januarie",
    "February" : "Februarie",
    "March" : "Maart",
    "April" : "April",
    "May" : "Mei",
    "June" : "Junie",
    "July" : "Julie",
    "August" : "Augustus",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mrt.",
    "Apr." : "Apr.",
    "May." : "Mei.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "Settings" : "Instellings",
    "Saving..." : "Stoor...",
    "Dismiss" : "Wys af",
    "seconds ago" : "sekondes gelede",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Die wagwoordherstelskakel is na u e-pos gestuur. Indien u dit nie binne ’n redelike tyd ontvang nie, gaan u gemorsposvouers na.<br>Vra u administrateur om hulp indien dit nie daar is nie.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "U lêers is geënkripteer. Indien u nie ’n verhaalsleutel geaktiveer het nie, sal daar geen manier wees om  u data terug te kry nadat u wagwoord herstel is nie. <br />Kontak u administrateur alvorens u voortgaan indien u onseker is. <br />Wil u regtig voortgaan?",
    "I know what I'm doing" : "Ek weet wat ek doen",
    "Password can not be changed. Please contact your administrator." : "Wagwoord kan nie verander word nie. Kontak u stelseladministrateur.",
    "No" : "Nee",
    "Yes" : "Ja",
    "Choose" : "Kies",
    "Error loading file picker template: {error}" : "Lêerkiesersjabloonlaaifout: {error}",
    "Ok" : "Goed",
    "Error loading message template: {error}" : "Boodskapsjabloonlaaifout: {error}",
    "read-only" : "leesalleen",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} lêerkonflik","{count} lêerkonflikte"],
    "One file conflict" : "Een lêerkonflik",
    "New Files" : "Nuwe Lêers",
    "Already existing files" : "Bestaande lêers",
    "Which files do you want to keep?" : "Welke lêers wil u hou?",
    "Cancel" : "Kanselleer",
    "Continue" : "Gaan voort",
    "(all selected)" : "(alles gekies)",
    "({count} selected)" : "({count} gekies)",
    "Error loading file exists template" : "Bestaandelêersjabloonlaaifout",
    "Very weak password" : "Baie swak wagwoord",
    "Weak password" : "Swak wagwoord",
    "So-so password" : "Matige wagwoord",
    "Good password" : "Goeie wagwoord",
    "Strong password" : "Sterk wagwoord",
    "Shared" : "Gedeel",
    "Shared with {recipients}" : "Gedeel met {recipients}",
    "Error" : "Fout",
    "Error while sharing" : "Fout tydens deel",
    "Error while unsharing" : "Fout tydens deelherroeping",
    "The public link will expire no later than {days} days after it is created" : "Die openbare skakel sal nie later nie as {days} dae veral nadat dit geskep is",
    "Expiration" : "Verval",
    "Expiration date is required" : "Vervaldatum word benodig",
    "Delete {link}" : "Skrap {link}",
    "Remove link" : "Verwyder skakel",
    "Link" : "Skakel",
    "Create public link" : "Skep openbare skakel",
    "Edit" : "Wysig",
    "Remove" : "Verwyder",
    "Copy to clipboard" : "Kopieer na knipbord",
    "There are currently no link shares, you can create one" : "Daar is tans geen skakeldelings nie, u kan een skep",
    "Anyone with the link has access to the file/folder" : "Enigeen met die skakel het toegang tot die lêer/vouer",
    "Copied!" : "Gekopieer!",
    "Not supported!" : "Nie ondersteun nie!",
    "Press ⌘-C to copy." : "Druk ⌘-C om te kopieer.",
    "Press Ctrl-C to copy." : "Druk Ctrl-C om te kopieer.",
    "Choose a password" : "Kies ’n wagwoord",
    "Password required" : "Wagwoord benodig",
    "Name" : "Naam",
    "Filename" : "Lêernaam",
    "Password" : "Wagwoord",
    "Edit link share: {name}" : "Wysig deelskakel: {name}",
    "Create link share: {name}" : "Skep deelskakel: {name}",
    "Share" : "Deel",
    "Save" : "Bewaar",
    "Remove password" : "Verwyder wagwoord",
    "Share to Twitter. Opens in a new window." : "Deel na Twitter. Open in ’n nuwe venster.",
    "Share to Facebook. Opens in a new window." : "Deel na Facebook. Open in ’n nuwe venster.",
    "Share to Diaspora. Opens in a new window." : "Deel na Diaspora. Open in ’n nuwe venster.",
    "Share to Google+. Opens in a new window." : "Deel na Google+. Open in ’n nuwe venster.",
    "Share via email. Opens your mail client." : "Deel d.m.v. e-pos. Open u poskliënt.",
    "Email link to person" : "E-pos aan persoon",
    "Send link via email" : "Stuur skakel d.m.v. e-pos",
    "Sending" : "Stuur tans",
    "Shared with you and the group {group} by {owner}" : "Met u en die groep {group} gedeel deur {owner}",
    "Shared with you by {owner}" : "Met u gedeel deur {owner}",
    "group" : "groep",
    "notify by email" : "laat weet d.m.v. e-pos",
    "Unshare" : "Herroep deel",
    "can share" : "kan deel",
    "can edit" : "kan wysig",
    "create" : "skep",
    "change" : "verander",
    "delete" : "uitvee",
    "access control" : "toegang beheer",
    "Share details could not be loaded for this item." : "Hierdie item se deeldetails kon nie gelaai word nie.",
    "No users or groups found for {search}" : "Geen gebruikers of groepe gevind vir {search}",
    "No users found for {search}" : "Geen gebruikers gevind vir {search}",
    "An error occurred. Please try again" : "’n Fout het voorgekom. Probeer weer",
    "User" : "Gebruiker",
    "Group" : "Groep",
    "User and Groups" : "Gebruiker en Groepe",
    "Public Links" : "Openbare Skakels",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Deel met mense op ander ownClouds deur die sintaks gebruikernaam@voorbeeld.com/owncloud te gebruik",
    "Share with users…" : "Deel met gebruikers…",
    "Share with users, groups or remote users…" : "Deel met gebruikers, groepe of afstandsgebruikers…",
    "Share with users or groups…" : "Deel met gebruikers of groepe…",
    "Share with users or remote users…" : "Deel met gebruikers of afstandsgebruikers…",
    "Non-existing tag #{tag}" : "Niebestaande merkie #{tag}",
    "restricted" : "beperk",
    "invisible" : "onsigbaar",
    "({scope})" : "({scope})",
    "Delete" : "Skrap",
    "Rename" : "Hernoem",
    "The object type is not specified." : "Hierdie objektipe is nie gespesifiseer nie.",
    "Add" : "Voeg by",
    "Error loading dialog template: {error}" : "Dialoogsjabloonlaaifout: {error}",
    "unknown text" : "onbekende teks",
    "Hello world!" : "Dag wêreld!",
    "sunny" : "sonnig",
    "Hello {name}, the weather is {weather}" : "Dag {name}, die weer is {weather}",
    "Hello {name}" : "Dag {name}",
    "new" : "nuut",
    "_download %n file_::_download %n files_" : ["laai %n lêer af","laai %n lêers af"],
    "Updating to {version}" : "Werk tans by na {version}",
    "An error occurred." : "’n Fout het voorgekom.",
    "Please reload the page." : "Herlaai asb. die blad.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Die bywerking was onsuksesvol. Rapporteer hierdie probleem by <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud-gemeenskap</a>.",
    "The update was successful. There were warnings." : "Die bywerking was suksesvol. Daar was waarskuwings.",
    "The update was successful. Redirecting you to ownCloud now." : "Die bywerking was suksesvol. U word nou na ownCloud herlei.",
    "Personal" : "Persoonlik",
    "Users" : "Gebruikers",
    "Apps" : "Toepassings",
    "Admin" : "Admin",
    "Help" : "Hulp",
    "Access forbidden" : "Toegang verbode",
    "File not found" : "Lêer nie gevind",
    "The share will expire on %s." : "Die deling sal op %s verval.",
    "Cheers!" : "Groete!",
    "Internal Server Error" : "Internebedienerfout",
    "Technical details" : "Tegniese details",
    "Remote Address: %s" : "Afstandsadres: %s",
    "Request ID: %s" : "Versoek-ID: %s",
    "Type: %s" : "Tipe: %s",
    "Code: %s" : "Kode: %s",
    "Message: %s" : "Boodskap: %s",
    "File: %s" : "Lêer: %s",
    "Line: %s" : "Lyn: %s",
    "Imprint" : "Afdruk",
    "Create an <strong>admin account</strong>" : "Skep ’n <strong>adminrekening</strong>",
    "Username" : "Gebruikersnaam",
    "Data folder" : "Datavouer",
    "Configure the database" : "Stel databasis op",
    "Only %s is available." : "Slegs %s is beskikbaar.",
    "Database user" : "Databasisgebruiker",
    "Database password" : "Databasiswagwoord",
    "Database name" : "Databasisnaam",
    "Database tablespace" : "Databasis tabelspasie",
    "Database host" : "Databasis gasheer",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Spesifiseer die poortnommer saam met die gasheernaam (bv. localhost: 5432).",
    "Finish setup" : "Maak opstelling klaar",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Goeiedag,<br><br>ons wil u laat weet dat %s <strong>%s</strong> met u gedeel het.<br><a href=\"%s\">Bekyk!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Hierdie toepassing benodig JavaScript om reg te werk. {linkstart}Aktiveer JavaScript{linkend} en herlaai die blad.",
    "Menu" : "Kieslys",
    "Log out" : "Teken uit",
    "Search" : "Soek",
    "Please contact your administrator." : "Kontak u stelseladministrateur.",
    "An internal error occurred." : "’n Interne fout het voorgekom.",
    "Please try again or contact your administrator." : "Probeer weer of kontak u stelseladministrateur.",
    "Login" : "Teken Aan",
    "Username or email" : "Gebruikersnaam of e-pos",
    "Wrong password. Reset it?" : "Verkeerde wagwoord. Herstel dit?",
    "Wrong password." : "Verkeerde wagwoord.",
    "Stay logged in" : "Bly aangeteken",
    "Alternative Logins" : "Alternatiewe aantekeninge",
    "Use the following link to reset your password: {link}" : "Gebruik die volgende skakel om u wagwoord te herstel: {link}",
    "New password" : "Nuwe wagwoord",
    "New Password" : "Nuwe Wagwoord",
    "Reset password" : "Herstel wagwoord"
},
"nplurals=2; plural=(n != 1);");
